@@ -4,23 +4,27 @@
 # TADA Tadashi <sho@spc.gr.jp> holds the copyright of Config class.
 
 module Hiki
-  VERSION = '0.8.8.1'
-  RELEASE_DATE = '2009-08-16'
+  VERSION = '1.0.0'
+  RELEASE_DATE = '2013-03-30'
 end
 
 # For backward compatibility
 HIKI_VERSION  = Hiki::VERSION
 HIKI_RELEASE_DATE = Hiki::RELEASE_DATE
 
-require 'cgi'
+require 'cgi' unless Object.const_defined?(:Rack)
+require 'hiki/request'
+require 'hiki/response'
+require 'hiki/util'
 require 'hiki/command'
 
 module Hiki
   PATH  = "#{File.dirname(File.dirname(__FILE__))}"
 
   class Config
-    def initialize
-      load
+    include ::Hiki::Util
+    def initialize(config_path = 'hikiconf.rb')
+      load(config_path)
       load_cgi_conf
 
       load_messages
@@ -38,19 +42,7 @@ module Hiki
       # repository class
       @repos = Hiki.const_get("Repos#{@repos_type.capitalize}").new(@repos_root, @data_path)
 
-      instance_variables.each do |v|
-        v = v.to_s
-        v.sub!( /@/, '' )
-        instance_eval( <<-SRC
-        def #{v}
-          @#{v}
-        end
-        def #{v}=(p)
-          @#{v} = p
-        end
-        SRC
-        )
-      end
+      self.class.__send__ :attr_accessor, *instance_variables.map{|v| v.to_s.sub('@', '') }
 
       bot = ["googlebot", "Hatena Antenna", "moget@goo.ne.jp"]
       bot += @options['bot'] || []
@@ -93,6 +85,7 @@ module Hiki
     end
 
     def base_url
+      return '' if Object.const_defined?(:Rack)
       unless @base_url
         if !ENV['SCRIPT_NAME']
           @base_url = ''
@@ -127,12 +120,21 @@ module Hiki
       end
     end
 
+    def read_layout
+      if mobile_agent?
+        path = File.join(@template_path, "i.layout.html")
+      else
+        path = File.join(@template_path, "layout.html")
+      end
+      File.read(path)
+    end
+
     private
 
     # loading hikiconf.rb in current directory
-    def load
+    def load(config_path = 'hikiconf.rb')
       @options = {}
-      eval( File.open( "hikiconf.rb" ){|f| f.read }.untaint, binding, "(hikiconf.rb)", 1 )
+      eval( File.open(config_path){|f| f.read }.untaint, binding, "(#{config_path})", 1 )
       formaterror if $data_path
 
       raise 'No @data_path variable.' unless @data_path
@@ -156,7 +158,7 @@ module Hiki
       @style         ||= 'default'
       @hilight_keys    = true if @hilight_keys.nil?
       @plugin_debug  ||= false
-      @charset       ||= 'EUC-JP'
+      @charset       ||= 'UTF-8'
       @database_type ||= 'flatfile'
       @cgi_name        = './' if !@cgi_name || @cgi_name.empty?
       @admin_name    ||= 'admin'
@@ -217,14 +219,19 @@ module Hiki
       begin
         cgi_conf = File.open( @config_file ){|f| f.read }.untaint
         cgi_conf.gsub!( /^[@$]/, '' )
-        def_vars = ''
-        variables.each do |var| def_vars << "#{var} = nil\n" end
-        eval( def_vars )
+        def_vars1 = ''
+        def_vars2 = ''
+        variables.each do |var|
+          def_vars1 << "#{var} = nil\n"
+          def_vars2 << "@#{var} = #{var} unless #{var} == nil\n"
+        end
+        b = binding.taint
+        eval( def_vars1, b )
         Thread.start {
           $SAFE = 4
-          eval( cgi_conf, binding, "(hiki.conf)", 1 )
+          eval( cgi_conf, b, "(hiki.conf)", 1 )
         }.join
-        variables.each do |var| eval "@#{var} = #{var} if #{var} != nil" end
+        eval( def_vars2, b )
       rescue IOError, Errno::ENOENT
       end
       @mail = [@mail].flatten # for backward compatibility
