@@ -3,6 +3,8 @@
 # Copyright (C) 2003, Yasuo Itabashi <yasuo_itabashi{@}hotmail.com>
 # You can distribute this under GPL.
 
+require 'hiki/util'
+
 module Hiki
   class HikifarmReposBase
     def initialize(root, data_root)
@@ -31,16 +33,25 @@ module Hiki
     def initialize(root, data_path)
       @root = root
       @data_path = data_path
+      @text_dir = File.join(data_path, "text")
     end
 
     def commit(page, log = nil)
       raise "Please override this function."
     end
 
+    def commit_with_content(page, content, log = nil)
+      raise "Please override this function."
+    end
+
     def delete(page, log = nil)
       raise "Please override this function."
     end
 
+    def rename(old_page, new_page)
+      raise "Please override this function."
+    end
+
     def get_revision(page, revision)
       raise "Please override this function."
     end
@@ -49,6 +60,19 @@ module Hiki
       raise "Please override this function."
     end
 
+    def pages
+      entries = Dir.entries(File.join(@data_path, "text")).reject{|entry|
+        entry =~ /\A\./ || File.directory?(entry)
+      }.map{|entry| unescape(entry) }
+      if block_given?
+        entries.each do |entry|
+          yield entry
+        end
+      else
+        entries
+      end
+    end
+
     private
 
     def default_msg
@@ -73,16 +97,24 @@ module Hiki
   end
 
   class ReposDefault < ReposBase
+    include Hiki::Util
+
     def commit(page, log = nil)
     end
 
+    def commit_with_content(page, content, log = nil)
+    end
+
     def delete(page, log = nil)
     end
 
+    def rename(old_page, new_page)
+    end
+
     def get_revision(page, revision)
       revision = revision.to_i
       begin
-        File::read("#{rev_path(revision)}/#{page.escape.untaint}")
+        File::read("#{rev_path(revision)}/#{escape(page).untaint}")
       rescue
         ''
       end
@@ -90,8 +122,8 @@ module Hiki
 
     def revisions(page)
       rev = []
-      rev << [2, File.mtime("#{rev_path(2)}/#{page.escape.untaint}").localtime.strftime('%Y/%m/%d %H:%M:%S'), '', 'current']
-      rev << [1, File.mtime("#{rev_path(1)}/#{page.escape.untaint}").localtime.strftime('%Y/%m/%d %H:%M:%S'), '', 'backup'] if File.exist?("#{rev_path(1)}/#{page.escape.untaint}")
+      rev << [2, File.mtime("#{rev_path(2)}/#{escape(page).untaint}").localtime.strftime('%Y/%m/%d %H:%M:%S'), '', 'current']
+      rev << [1, File.mtime("#{rev_path(1)}/#{escape(page).untaint}").localtime.strftime('%Y/%m/%d %H:%M:%S'), '', 'backup'] if File.exist?("#{rev_path(1)}/#{escape(page).untaint}")
       rev
     end
 
