@@ -66,6 +66,8 @@ module Hiki
   end
 
   class ReposSvn < ReposBase
+    include Hiki::Util
+
     def initialize(root, data_path)
       super
       if /^[a-z]:/i =~ @root
@@ -77,24 +79,46 @@ module Hiki
     end
 
     def commit(page, msg = default_msg)
-      Dir.chdir("#{@data_path}/text") do
-        system("svn add -q -- #{page.escape}".untaint)
-        system("svn propdel -q svn:mime-type -- #{page.escape}".untaint)
+      escaped_page = escape(page).untaint
+      Dir.chdir(@text_dir) do
+        found = system("svn status -q -- #{escaped_page} | grep -q #{escaped_page}")
+        system("svn add -q -- #{escaped_page}") unless found
+        system("svn propdel -q svn:mime-type -- #{escaped_page}")
+        system("svn ci -q --force-log -m \"#{msg}\"")
+      end
+    end
+
+    def commit_with_content(page, content, msg = default_msg)
+      escaped_page = escape(page).untaint
+      File.open(File.join(@text_dir, escaped_page), "w+") do |file|
+        file.write(content)
+      end
+      commit(page)
+    end
+
+    def delete(page, msg = default_msg)
+      escaped_page = escape(page).untaint
+      Dir.chdir(@text_dir) do
+        system("svn remove -q -- #{escaped_page}")
         system("svn ci -q --force-log -m \"#{msg}\"".untaint)
       end
     end
 
-    def delete(page, msg = default_msg)
-      Dir.chdir("#{@data_path}/text") do
-        system("svn remove -q -- #{page.escape}".untaint)
-        system("svn ci -q --force-log -m \"#{msg}\"".untaint)
+    def rename(old_page, new_page)
+      old_page = escape(old_page.untaint)
+      new_page = escape(new_page.untaint)
+      Dir.chdir(@text_dir) do
+        raise ArgumentError, "#{new_page} has already existed." if File.exist?(new_page)
+        system("svn", "mv", "-q", old_page, new_page)
+        system("svn", "commit", "-q", "-m", "'Rename #{old_page} to #{new_page}'")
       end
     end
 
     def get_revision(page, revision)
       ret = ''
-      Dir.chdir("#{@data_path}/text") do
-        open("|svn cat -r #{revision.to_i} #{page.escape.untaint}") do |f|
+      escaped_page = escape(page).untaint
+      Dir.chdir(@text_dir) do
+        open("|svn cat -r #{revision.to_i} #{escaped_page}") do |f|
           ret = f.read
         end
       end
@@ -103,10 +127,11 @@ module Hiki
 
     def revisions(page)
       require 'time'
+      escaped_page = escape(page).untaint
       log = ''
       revs = []
-      Dir.chdir("#{@data_path}/text") do
-        open("|svn log #{page.escape.untaint}") do |f|
+      Dir.chdir(@text_dir) do
+        open("|svn log #{escaped_page}") do |f|
           log = f.read
         end
       end
