@@ -2,9 +2,11 @@ require 'hiki/repos/svn'
 
 module Hiki
   # The hikifarm has only one repository
-  class ReposSvnsingle < ReposSvnBase
+  class HikifarmReposSvnsingle < HikifarmReposSvnBase
     def setup
       system("svnadmin create #{@root}")
     end
   end
+
+  class ReposSvnsingle < ReposSvn; end
 end
