@@ -1,11 +1,15 @@
+# -*- coding: utf-8 -*-
 # $Id: util.rb,v 1.44 2005-12-25 07:03:06 yanagita Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 require 'nkf'
-require 'cgi'
+require 'cgi' unless Object.const_defined?(:Rack)
+require 'erb'
 
-autoload( :Document, 'docdiff' )
-autoload( :Diff, 'docdiff' )
+require 'docdiff/difference'
+require 'docdiff/document'
+require 'docdiff/view'
+require 'docdiff/diff/unidiff'
 
 class String
   # all instance methods added in String class will be obsoleted in the
@@ -23,20 +27,24 @@ class String
     NKF.nkf('-m0 -j', self)
   end
 
+  def to_utf8
+    NKF.nkf('-m0 -w', self)
+  end
+
   def escape
-    CGI.escape(self)
+    Hiki::Util.escape(self)
   end
 
   def unescape
-    CGI.unescape(self)
+    Hiki::Util.unescape(self)
   end
 
   def escapeHTML
-    CGI.escapeHTML(self)
+    Hiki::Util.escape_html(self)
   end
 
   def unescapeHTML
-    CGI.unescapeHTML(self)
+    Hiki::Util.unescape_html(self)
   end
 
   def sanitize
@@ -52,8 +60,82 @@ module Hiki
   class PluginException < Exception; end
 
   module Util
-    def plugin_error( method, e )
-      msg = "<strong>#{e.class} (#{e.message.escapeHTML}): #{method.escapeHTML}</strong><br>"
+    include ERB::Util
+
+    # dead copy from cgi.rb (Ruby1.8)
+    # URL-encode a string.
+    #   url_encoded_string = escape("'Stop!' said Fred")
+    #      # => "%27Stop%21%27+said+Fred"
+    def escape(string)
+      string.gsub(/([^ a-zA-Z0-9_.-]+)/n) do
+        '%' + $1.unpack('H2' * $1.bytesize).join('%').upcase
+      end.tr(' ', '+')
+    end
+
+    # dead copy from cgi.rb (Ruby1.8)
+    # URL-decode a string.
+    #   string = unescape("%27Stop%21%27+said+Fred")
+    #      # => "'Stop!' said Fred"
+    def unescape(string)
+      string.tr('+', ' ').gsub(/((?:%[0-9a-fA-F]{2})+)/n) do
+        [$1.delete('%')].pack('H*')
+      end
+    end
+
+    # dead copy from cgi.rb (Ruby1.8)
+    # Escape special characters in HTML, namely &\"<>
+    #   escapeHTML('Usage: foo "bar" <baz>')
+    #      # => "Usage: foo &quot;bar&quot; &lt;baz&gt;"
+    def escapeHTML(string)
+      string.gsub(/&/n, '&amp;').gsub(/\"/n, '&quot;').gsub(/>/n, '&gt;').gsub(/</n, '&lt;')
+    end
+
+    # dead copy from cgi.rb (Ruby1.8)
+    # Unescape a string that has been HTML-escaped
+    #   unescapeHTML("Usage: foo &quot;bar&quot; &lt;baz&gt;")
+    #      # => "Usage: foo \"bar\" <baz>"
+    def unescapeHTML(string)
+      string.gsub(/&(amp|quot|gt|lt|\#[0-9]+|\#x[0-9A-Fa-f]+);/n) do
+        match = $1.dup
+        case match
+        when 'amp'                 then '&'
+        when 'quot'                then '"'
+        when 'gt'                  then '>'
+        when 'lt'                  then '<'
+        when /\A#0*(\d+)\z/n       then
+          if Integer($1) < 256
+            Integer($1).chr
+          else
+            if Integer($1) < 65536 and $KCODE[0] == ?U
+              [Integer($1)].pack("U")
+            else
+              "&##{$1};"
+            end
+          end
+        when /\A#x([0-9a-f]+)\z/ni then
+          if $1.hex < 256
+            $1.hex.chr
+          else
+            if $1.hex < 65536 and $KCODE[0] == ?U
+              [$1.hex].pack("U")
+            else
+              "&#x#{$1};"
+            end
+          end
+        else
+          "&#{match};"
+        end
+      end
+    end
+
+    alias escape_html escapeHTML
+    alias h escapeHTML
+    alias unescape_html unescapeHTML
+
+    module_function :escape, :unescape, :escape_html, :h, :unescape_html
+
+    def plugin_error(method, e)
+      msg = "<strong>#{e.class} (#{h(e.message)}): #{h(method)}</strong><br>"
       msg << "<strong>#{e.backtrace.join("<br>\n")}</strong>" if @conf.plugin_debug
       msg
     end
@@ -62,12 +144,12 @@ module Hiki
       "?c=#{cmd};#{param}"
     end
 
-    def title( s )
-      CGI.escapeHTML( "#{@conf.site_name} - #{s}" )
+    def title(s)
+      h("#{@conf.site_name} - #{s}")
     end
 
     def view_title( s )
-      %Q!<a href="#{@conf.cgi_name}#{cmdstr('search', "key=#{s.escape}") }">#{s.escapeHTML}</a>!
+      %Q!<a href="#{@conf.cgi_name}#{cmdstr('search', "key=#{escape(s)}") }">#{h(s)}</a>!
     end
 
     def format_date( tm )
@@ -75,9 +157,9 @@ module Hiki
     end
 
     def get_common_data( db, plugin, conf )
-      data = Hash.new
+      data = {}
       data[:author_name] = conf.author_name
-      data[:view_style]  = conf.use_sidebar ? CGI.escapeHTML( conf.main_class ) : 'hiki' # for tDiary theme
+      data[:view_style]  = conf.use_sidebar ? h(conf.main_class) : 'hiki' # for tDiary theme
       data[:cgi_name]    = conf.cgi_name
       if conf.use_sidebar
         t = db.load_cache( conf.side_menu )
@@ -90,7 +172,7 @@ module Hiki
         f = conf.formatter.new( t, db, plugin, conf, 's' )
         data[:sidebar]   = f.to_s
         data[:main_class]    = conf.main_class
-        data[:sidebar_class] = CGI.escapeHTML( conf.sidebar_class )
+        data[:sidebar_class] = h(conf.sidebar_class)
       else
         data[:sidebar] = nil
       end
@@ -98,8 +180,8 @@ module Hiki
     end
 
     def word_diff( src, dst, digest = false )
-      src_doc = Document.new( src, 'EUC-JP', CharString.guess_eol($/) )
-      dst_doc = Document.new( dst, 'EUC-JP', CharString.guess_eol($/) )
+      src_doc = Document.new( src, @charset, CharString.guess_eol($/) )
+      dst_doc = Document.new( dst, @charset, CharString.guess_eol($/) )
       diff = compare_by_line_word( src_doc, dst_doc )
       overriding_tags = {
         :start_common => '',
@@ -114,15 +196,15 @@ module Hiki
         :end_after_change    => '</ins>',
       }
       if digest
-        return View.new( diff, src.encoding, src.eol ).to_html_digest(overriding_tags, false).to_s.gsub( %r|<br />|, '' ).gsub( %r|\n</ins>|, "</ins>\n" )
+        return View.new( diff, src.encoding, src.eol ).to_html_digest(overriding_tags, false).join.gsub( %r|<br />|, '' ).gsub( %r|\n</ins>|, "</ins>\n" ) #"
       else
-        return View.new( diff, src.encoding, src.eol ).to_html(overriding_tags, false).to_s.gsub( %r|<br />|, '' ).gsub( %r|\n</ins>|, "</ins>\n" )
+        return View.new( diff, src.encoding, src.eol ).to_html(overriding_tags, false).join.gsub( %r|<br />|, '' ).gsub( %r|\n</ins>|, "</ins>\n" ) #"
       end
     end
 
     def word_diff_text( src, dst, digest = false )
-      src_doc = Document.new( src, 'EUC-JP' )
-      dst_doc = Document.new( dst, 'EUC-JP' )
+      src_doc = Document.new( src, @charset)
+      dst_doc = Document.new( dst, @charset)
       diff = compare_by_line_word( src_doc, dst_doc )
       if digest
         return View.new( diff, src.encoding, src.eol ).to_wdiff_digest({}, false).join.gsub( %r|\n\+\}|, "+}\n" )
@@ -132,16 +214,15 @@ module Hiki
     end
 
     def unified_diff( src, dst, context_lines = 3 )
-      return Diff.new(src.to_a, dst.to_a).ses.unidiff( '', context_lines )
+      return h(Diff.new(src.split(/^/), dst.split(/^/)).ses.unidiff( '', context_lines ))
     end
 
-    def redirect(cgi, url, cookies = nil)
+    def redirect(request, url, cookies = nil)
       url.sub!(%r|/\./|, '/')
       header = {}
       header['cookie'] = cookies if cookies
       header['type'] = 'text/html'
-      print cgi.header(header)
-      print %Q[
+      body = %Q[
                <html>
                <head>
                <meta http-equiv="refresh" content="0;url=#{url}">
@@ -149,6 +230,16 @@ module Hiki
                </head>
                <body>Wait or <a href="#{url}">Click here!</a></body>
                </html>]
+      response = Hiki::Response.new(body, 200, header)
+      if Object.const_defined?(:Rack)
+        cookies = response.header.delete('cookie')
+        if cookies
+          cookies.each do |cookie|
+            response.set_cookie(cookie.name, cookie.value)
+          end
+        end
+      end
+      response
     end
 
     def sendmail(subject, body)
@@ -164,7 +255,7 @@ module Hiki
           smtp.send_mail <<EndOfMail, from_addr, *to_addrs
 From: #{from_addr}
 To: #{to_addrs.join(",")}
-Subject: #{NKF.nkf('-M', subject)}
+Subject: #{NKF.nkf('-Mj', subject)}
 Date: #{Time.now.rfc2822}
 MIME-Version: 1.0
 Content-Type: text/plain; charset="iso-2022-jp"
@@ -185,7 +276,7 @@ REMOTE_HOST = #{ENV['REMOTE_HOST']}
 EOS
       body << "REMOTE_USER = #{ENV['REMOTE_USER']}\n" if ENV['REMOTE_USER']
       body << <<EOS
-        URL = #{@conf.index_url}?#{page.escape}
+        URL = #{@conf.index_url}?#{escape(page)}
 #{'-' * 25}
 #{text}
 EOS
@@ -221,58 +312,78 @@ EOS
       end
     end
 
-    def euc_to_utf8(str)
-      if NKF.const_defined?(:UTF8)
-        return NKF.nkf('-m0 -w', str)
-      else
-        begin
-          require 'uconv'
-        rescue LoadError
+    if Object.const_defined?(:Encoding)
+      # TODO remove this method in future release
+      def euc_to_utf8(str)
+        str.encode("UTF-8", "EUC-JP")
+      end
+
+      # TODO remove this method in future release
+      def utf8_to_euc(str)
+        str.encode("EUC-JP", "UTF-8")
+      end
+
+      # TODO remove this method in future release
+      def to_native(str, charset=nil)
+        str.encode(@charset, charset)
+      end
+    else
+      # TODO remove this method in future release
+      def euc_to_utf8(str)
+        if NKF.const_defined?(:UTF8)
+          return NKF.nkf('-m0 -w', str)
+        else
+          begin
+            require 'uconv'
+          rescue LoadError
             raise "Please update to Ruby >= 1.8.2, or install either uconv or rbuconv."
+          end
+          return Uconv.euctou8(str)
         end
-        return Uconv.euctou8(str)
       end
-    end
 
-    def utf8_to_euc(str)
-      if NKF.const_defined?(:UTF8)
-        return NKF.nkf('-m0 -e', str)
-      else
+      # TODO remove this method in future release
+      def utf8_to_euc(str)
+        if NKF.const_defined?(:UTF8)
+          return NKF.nkf('-m0 -e', str)
+        else
+          begin
+            require 'uconv'
+          rescue LoadError
+            raise "Please update to Ruby >= 1.8.2, or install either uconv or rbuconv."
+          end
+          return Uconv.u8toeuc(str)
+        end
+      end
+
+      # TODO remove this method in future release
+      def to_native(str, charset=nil)
+        # XXX to_charset will be 'utf-8' in the future version
         begin
-          require 'uconv'
-        rescue LoadError
-          raise "Please update to Ruby >= 1.8.2, or install either uconv or rbuconv."
-        end
-        return Uconv.u8toeuc(str)
-      end
-    end
-
-    def to_native(str, charset=nil)
-      # XXX to_charset will be 'utf-8' in the future version
-      begin
-        Iconv.conv(@charset, charset || 'utf-8', str)
-      rescue
-        from = case charset
-               when /^utf-8$/i
-                 'W'
-               when /^shift_jis/i
-                 'S'
-               when /^EUC-JP/i
-                 'E'
-               else
-                 ''
-               end
-        to = case @charset
+          Iconv.conv(@charset, charset || 'utf-8', str)
+        rescue
+          from = case charset
+                 when /^utf-8$/i
+                   'W'
+                 when /^shift_jis/i
+                   'S'
+                 when /^EUC-JP/i
+                   'E'
+                 else
+                   ''
+                 end
+          to = case @charset
                when /^utf-8$/i
                  'w'
-               when /^shift_jis/i
+               when /\Ashift_jis\z/i
                  's'
-               when /^EUC-JP/i
+               when /\Aeuc-jp\z/i
                  'e'
                else
                  'e' # XXX what should we use?
                end
-        NKF::nkf("-m0 -#{from}#{to}", str)
+          NKF.nkf("-m0 -#{from}#{to}", str)
+        end
       end
     end
 
@@ -285,9 +396,9 @@ EOS
       words = Difference.new
       lines.each{|line|
         if line.first == :change_elt
-          before_change = Document.new(line[1].to_s,
+          before_change = Document.new((line[1] || []).join,
                                        doc1.encoding, doc1.eol)
-          after_change  = Document.new(line[2].to_s,
+          after_change  = Document.new((line[2] || []).join,
                                        doc2.encoding, doc2.eol)
           Difference.new(before_change.split_to_word,
                          after_change.split_to_word).each{|word|
