@@ -142,7 +142,7 @@ is expected to accept only one argument(URL).")
     (hiki-load-init-file)
     (setq hiki-init t)))
 
-;;; Խ⡼ (hiki-edit-*)
+;;; 編集モード (hiki-edit-*)
 
 (define-derived-mode hiki-edit-mode text-mode "Hiki Edit"
   "Major mode for Hiki editing.
@@ -201,9 +201,9 @@ If you want to set up your own key bindings, use `hiki-edit-mode-hook'."
     (setq hiki-site-list hiki-list)))
 
 (defun hiki-read-site-name (&optional string)
-  "̾ߥ˥ХåեɤߡȾΥꥹȤ֤
+  "サイト名をミニバッファから読み、サイト情報のリストを返す。
 
-STRING  non-nil ʤ顢򥵥̾Ȥ롣"
+STRING が non-nil なら、それをサイト名とする。"
   (let* ((selected (car hiki-site-list))
 	 (default (or (hiki-site-name) (car selected))))
     (assoc 
@@ -231,9 +231,9 @@ STRING  non-nil ʤ顢򥵥̾Ȥ롣"
 		   (cdr (assoc site-name hiki-pagename-history)) 
 		   nil nil arg nil arg))
 
-;;; navi2ch-read-char 򻲹ͤˤƤޤ
+;;; navi2ch-read-char を参考にしてます。
 (defun hiki-read-char (prompt)
-  "PROMPT (non-nil ξ) ɽ `read-char' ƤӽФ"
+  "PROMPT (non-nil の場合) を表示して `read-char' を呼び出す。"
   (let ((cursor-in-echo-area t)
 	c)
     (if prompt
@@ -243,7 +243,7 @@ STRING  non-nil ʤ顢򥵥̾Ȥ롣"
 	(message "%s%c" prompt c))
     c))
 
-;;; navi2ch-read-char-with-retry 򻲹ͤˤƤޤ
+;;; navi2ch-read-char-with-retry を参考にしてます。
 (defun hiki-read-char-with-retry (prompt retry-prompt list)
   (let ((retry t) c)
     (while retry
@@ -285,17 +285,17 @@ STRING  non-nil ʤ顢򥵥̾Ȥ롣"
     str))
 
 (defun hiki-edit-next-anchor (&optional prev)
-  "Υ󥫡ذư롣
+  "次のアンカーへ移動する。
 
-PREV  non-nil ʤСΥ󥫡ذư롣"
+PREV が non-nil ならば、前のアンカーへ移動する。"
   (interactive "P")
   (goto-char (or (car (hiki-search-anchor (point) prev))
 		 (point))))
 
 (defun hiki-search-anchor (point &optional prev)
-  "POINT Ǥᤤ󥫡õ
+  "POINT から最も近いアンカーを探す。
 
-Ĥä (beginning . end) 򡢸Ĥʤä nil  ֤"
+見つかったら (beginning . end) を、見つからなかったら nil を 返す"
   (let ((case-fold-search nil)
 	(alist hiki-anchor-regexp-alist)
 	result)
@@ -321,7 +321,7 @@ PREV  non-nil ʤСΥ󥫡ذư롣"
 	(rename-buffer name t))))
 
 (defun hiki-edit-url (str &optional url-encoded)
-  "URL ꤷԽ롣"
+  "URL を指定して編集する。"
   (interactive "sURL: ")
   (let (url pagename site-info)
     (or	(string-match "^\\(http://[^?]+\\)\\?\\(.+\\)$" str)
@@ -360,15 +360,15 @@ PREV  non-nil ʤСΥ󥫡ذư롣"
       (hiki-index site-info t pagename))))
 
 (defun hiki-edit-reload ()
-  "ԽΥڡɤ롣"
+  "現在編集中のページをリロードする。"
   (interactive)
   (let ((selected-pagename hiki-pagename))
     (hiki-edit)))
 
 (defun hiki-edit (&optional select-site)
-  "ڡ̾ꤷԽ롣
+  "ページ名を指定して編集する。
 
-SELECT-SITE  non-nil λϡSITE̾ꤹ롣"
+SELECT-SITE が non-nil の時は、SITE名も指定する。"
   (interactive "P")
   (hiki-initialize)
   (let ((point (point))
@@ -397,7 +397,7 @@ SELECT-SITE  non-nil λϡSITE̾ꤹ롣"
       (set-window-start (selected-window) start)
       (goto-char point))))
 
-;;; ⡼(hiki-index-*)
+;;; 一覧モード(hiki-index-*)
 
 (define-derived-mode hiki-index-mode text-mode "Hiki Index"
   "Major mode for Hiki index.
@@ -425,10 +425,10 @@ If you want to set up your own key bindings, use `hiki-index-mode-hook'."
   )
 
 (defun hiki-index (&optional site-info refetch pagename)
-  "⡼ɤ롣
+  "一覧モードに入る。
 
-SITE-INFO ꤵƤʤСߥ˥Хåեɤ߹ࡣ
-REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
+SITE-INFO が指定されていなければ、ミニバッファから読み込む。
+REFETCH が nil ですでにバッファが存在するなら、HTTP GET しない。"
   (interactive "P")
   (hiki-initialize)
   (let (buf)
@@ -440,10 +440,10 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
     (unless pagename (delete-other-windows))))
 
 (defun hiki-display-index (site-info &optional refetch pagename)
-  "ɽХåե֤
+  "一覧を表示し、バッファを返す。
 
-REFETCH  nil Ǵ˥Хåե¸ߤʤ顢HTTP GET ʤ
-PAGENAME бԤС򤽤˰ư롣 "
+REFETCH が nil で既にバッファが存在するなら、HTTP GET しない。
+PAGENAME に対応した行があれば、カーソルをそこに移動する。 "
   (let ((old-buf (current-buffer))
 	(buf (hiki-index-get-buffer-create site-info)))
     (switch-to-buffer buf)
@@ -470,7 +470,7 @@ PAGENAME бԤС򤽤˰ư롣 "
     buf))
 
 (defun hiki-index-get-buffer-create (site-info)
-  "ɽѤΥХåե֤"
+  "一覧表示用のバッファを返す。"
   (let ((buf-name (hiki-index-buffer-name site-info)))
     (or (get-buffer buf-name)
 	(progn
@@ -496,9 +496,9 @@ PAGENAME бԤС򤽤˰ư롣 "
 	    extra)))
 
 (defun hiki-index-display-page (&optional refetch)
-  "߹ԤΥڡɽ롣
+  "現在行のページを表示する。
 
-REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
+REFETCH が nil ですでにバッファが存在するなら、HTTP GET しない。"
   (interactive)
   (let ((point (point))
 	(page-info (hiki-index-page-info-current-line))
@@ -516,9 +516,9 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
     (goto-char point)))
 
 (defun hiki-index-display-page-next (&optional refetch)
-  "߹ԤΥڡɽ롣ǤɽƤϥ뤹롣
+  "現在行のページを表示する。すでに表示されている時はスクロールする。
 
-REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
+REFETCH が nil ですでにバッファが存在するなら、HTTP GET しない。"
   (interactive)
   (let ((page-info (hiki-index-page-info-current-line))
 	(old-win (selected-window))
@@ -532,19 +532,19 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
 	(let ((other-window-scroll-buffer buf)
 	      (start (window-start win)))
 	  (scroll-other-window)
-;;; ʤϼԤ˰ܤ롣
+;;; スクロール出来ない時は次行に移る。
 ;;;	  (when (= (window-start win) start)
 ;;;	    (forward-line)
 ;;;	    (hiki-index-display-page refetch))
 	  )))))
 
 (defun hiki-index-edit-page-current-line ()
-  "߹ԤΥڡԽ롣"
+  "現在行のページを編集する。"
   (interactive)
   (hiki-index-edit-page (nth 1 (hiki-index-page-info-current-line))))
 
 (defun hiki-index-edit-page (&optional pagename)
-  "ڡԽ롣"
+  "ページを編集する。"
   (interactive)
   (let ((index-buf (current-buffer))
 	edit-buf start)
@@ -565,7 +565,7 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
       (switch-to-buffer edit-buf))))
 
 (defun hiki-index-page-info-current-line ()
-  "߹ԤΥڡ(list)֤"
+  "現在行のページ情報(list)を返す。"
   (let (num)
     (save-excursion
       (beginning-of-line)
@@ -576,7 +576,7 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
      (t nil))))
 
 (defun hiki-index-page-info (pagename)
-  "PAGENAME  page-info ֤Τʤ nil"
+  "PAGENAME の page-info を返す。知らなければ nil。"
   (let (result)
     (dolist (page-info hiki-index-page-info-list)
       (when (string= (nth 1 page-info) pagename)
@@ -584,12 +584,12 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
     result))
 
 (defun hiki-index-refetch-index ()
-  "κɤ߹ߤԤ"
+  "一覧の再読み込みを行う。"
   (interactive)
   (hiki-index hiki-site-info t (nth 1 (hiki-index-page-info-current-line))))
 
 (defun hiki-index-sort (&optional rev)
-  "ΥȤԤ"
+  "一覧のソートを行う"
   (interactive "P")
   (message "Sorting...")
   (hiki-index-sort-by 
@@ -598,7 +598,7 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
   (message "Sorting... done."))
 
 (defun hiki-index-suspend ()
-  "hiki-index Ǥ롣"
+  "hiki-index を一時中断する。"
   (interactive)
   (delete-other-windows)
   (dolist (elm hiki-page-buffer-alist)
@@ -606,7 +606,7 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
   (replace-buffer-in-windows (current-buffer)))
 
 (defun hiki-index-quit ()
-  "hiki-index λ롣"
+  "hiki-index を終了する。"
   (interactive)
   (let ((tmp hiki-page-buffer-alist))
     (delete-other-windows)
@@ -647,9 +647,9 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
 ;;; func
 
 (defun hiki-display-page (pagename site-info &optional refetch)
-  "ڡΤɽ
+  "ページのを表示する
 
-REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
+REFETCH が nil ですでにバッファが存在するなら、HTTP GET しない。"
   (let ((not-cancelled t)
 	result body keyword pagetitle password history point buf new-page)
     (setq buf (cdr (assoc (list (hiki-site-name site-info) pagename) 
@@ -697,7 +697,7 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
       result)))
 
 (defun hiki-edit-page (pagename site-info)
-  "PAGENAME Խ⡼ɤ롣Хåե֤"
+  "PAGENAME の編集モードに入る。バッファを返す。"
   (let ((result (hiki-display-page pagename site-info t)))
     (when result
       (setq hiki-md5hex (cdr (assq 'md5hex result)))
@@ -714,7 +714,7 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
       (current-buffer))))
 
 (defun hiki-fetch-index (site-info)
-  "ڡ롣"
+  "ページ一覧を取得する。"
   (let (indexes history (i 1)
                 (buf (hiki-http-request 'get "index" nil (hiki-site-url site-info))))
     (when (bufferp buf)
@@ -741,7 +741,7 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
       (reverse indexes))))
 
 (defun hiki-fetch-source (pagename site-url)
-  "Hiki  롣
+  "Hiki の ソースを取得する。
 
 '((md5hex . \"...\")
   (session-id . \"...\")
@@ -749,7 +749,7 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
   (pagetitle . (...)) 
   (keyword . (...)) 
   (update-timestamp . t/nil)
-  (password . t/nil)) ֤"
+  (password . t/nil)) を返す。"
   (let (buf start end pt result)
     (setq buf (hiki-http-request 'get "edit" pagename site-url))
     (when (bufferp buf)
@@ -848,7 +848,7 @@ REFETCH  nil ǤǤ˥Хåե¸ߤʤ顢HTTP GET ʤ"
       (hiki-edit-quit))))
 
 (defun hiki-conflict-show-diff ()
-  "ߤΥХåեȥФΥǡӤɽ롣"
+  "現在のバッファとサーバのデータを比較し、表示する。"
   (let 
       ((file1 (expand-file-name (make-temp-name "hiki") 
 				temporary-file-directory))
@@ -957,9 +957,9 @@ Otherwise replace all entity references within current buffer."
     (add-text-properties 0 (length string) properties string)))
 
 (defun hiki-prefix (str width)
-  "STR Ƭ WIDTHʸФ
+  "STR の先頭を WIDTH文字を取り出す。
 
-WIDTH ʤϡ˶򤬥ѥǥ󥰤롣"
+WIDTH に満たない場合は、末尾に空白がパディングされる。"
   (let (l (result "")
 	(w (string-width str)))
     (if (< w width)
