@@ -16,14 +16,14 @@ def bbs(level = 1)
   <<EOS
 <form action="#{@conf.cgi_name}" method="post">
   <div>
-    #{bbs_name_label}: <input type="text" name="name" value="#{name.escapeHTML}" size="10">
+    #{bbs_name_label}: <input type="text" name="name" value="#{h(name)}" size="10">
     #{bbs_subject_label}: <input type="text" name="subject" size="40"><br>
     <textarea cols="60" rows="8" name="msg"></textarea><br>
     <input type="submit" name="comment" value="#{bbs_post_label}">
     <input type="hidden" name="bbs_num" value="#{@bbs_num}">
     <input type="hidden" name="bbs_level" value="#{level}">
     <input type="hidden" name="c" value="plugin">
-    <input type="hidden" name="p" value="#{@page.escapeHTML}">
+    <input type="hidden" name="p" value="#{h(@page)}">
     <input type="hidden" name="plugin" value="bbs_post">
     <input type="hidden" name="session_id" value="#{@session_id}">
   </div>
@@ -32,14 +32,14 @@ EOS
 end
 
 def bbs_post
-  return '' if @conf.use_session && @session_id != @cgi['session_id']
+  return '' if @conf.use_session && @session_id != @request.params['session_id']
 
-  params     = @cgi.params
-  bbs_num    = (params['bbs_num'][0] || 0).to_i
-  bbs_level  = (params['bbs_level'][0] || 1).to_i
-  name       = params['name'][0].size == 0 ? bbs_anonymous_label : params['name'][0]
-  subject    = (params['subject'][0].size == 0 ? bbs_notitle_label : params['subject'][0])
-  msg        = params['msg'][0]
+  params     = @request.params
+  bbs_num    = (params['bbs_num'] || 0).to_i
+  bbs_level  = (params['bbs_level'] || 1).to_i
+  name       = params['name'].size == 0 ? bbs_anonymous_label : params['name']
+  subject    = (params['subject'].size == 0 ? bbs_notitle_label : params['subject'])
+  msg        = params['msg']
 
   return '' if msg.strip.size == 0
 
@@ -54,7 +54,7 @@ def bbs_post
     if /^\{\{bbs\b(:?[^\}]*)?\}\}/ =~ l && flag == false
       if count == bbs_num
         content << "#{l}\n"
-        content << @conf.parser.heading( "#{subject} - #{name} (#{format_date(Time::now)})\n", bbs_level )
+        content << @conf.parser.heading( "#{subject} - #{name} (#{format_date(Time.now)})\n", bbs_level )
         content << "#{msg}\n"
         content << "{{comment}}\n"
         flag = true
