@@ -1,22 +1,23 @@
+# -*- coding: utf-8 -*-
 # $Id: attach.rb,v 1.2 2005-06-17 05:03:43 fdiary Exp $
 # Copyright (C) 2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 def attach_files_label
-  'źեե'
+  '添付ファイル'
 end
 
 def attach_upload_label
-  'եź'
+  'ファイルの添付'
 end
 
 def detach_upload_label
-  'åե'
+  'チェックしたファイルを削除'
 end
 
 def attach_usage
        '<div><ul>
-   <li>źեեؤΥ󥫤ϡ{{attach_anchor(ե̾ [, ڡ̾])}}</li>
-   <li>źդեɽϡ{{attach_view(ե̾ [, ڡ̾])}}</li>
-   <li>źեڡȥեΰϡ{{attach_map}}</li>
+   <li>添付ファイルへのアンカは、{{attach_anchor(ファイル名 [, ページ名])}}</li>
+   <li>添付したファイルの表示は、{{attach_view(ファイル名 [, ページ名])}}</li>
+   <li>添付ページとファイルの一覧は、{{attach_map}}</li>
    </ul></div>'
 end
