@@ -17,7 +17,7 @@ def rank( n = 20 )
     p = a[name]
 
     t = "#{page_name(name)} (#{p[:count]})"
-    an = hiki_anchor( name.escape, t )
+    an = hiki_anchor(escape(name), t)
     s << "<li>#{an}\n"
     c = c + 1
   end
@@ -25,7 +25,9 @@ def rank( n = 20 )
   s
 end
 
-add_body_leave_proc do
-  @db.increment_hitcount( @page )
-  ''
+if @command == 'view'
+  add_body_leave_proc do
+    @db.increment_hitcount( @page )
+    ''
+  end
 end
