@@ -4,7 +4,7 @@
 def recent2( n = 20 )
   n = n > 0 ? n : 0
 
-  now = Time::now
+  now = Time.now
 
   l = @db.page_info.sort do |a, b|
     b[b.keys[0]][:last_modified] <=> a[a.keys[0]][:last_modified]
@@ -30,7 +30,7 @@ def recent2( n = 20 )
 
     cur_date = tm.strftime( @conf.msg_date_format )
     t = page_name(name)
-    an = hiki_anchor(name.escape, t)
+    an = hiki_anchor(escape(name), t)
     s << "<li title=\"#{cur_date}\">#{an} <span class=\"recent2\">(#{ps})</span>\n"
   end
   s << "</ul>\n"
