@@ -10,30 +10,28 @@ def src
 <head>
   <meta http-equiv="Content-Language" content="#{@conf.lang}">
   <meta http-equiv="Content-Type" content="text/html; charset= #{@conf.charset}">
-  <title>#{CGI::escapeHTML(page_name(@page))}</title>
+  <title>#{h(page_name(@page))}</title>
 </head>
 <body>
 <div>
 EOS
   page = @db.load( @page )
-  sources << (page ? page.escapeHTML.gsub(/\n/, "<br>\n").gsub(/ /, '&nbsp;') : 'load error.')
+  sources << (page ? h(page).gsub(/\n/, "<br>\n").gsub(/ /, '&nbsp;') : 'load error.')
   sources  << <<EOS
 </div>
 </body>
 </html>
 EOS
 
-  header = Hash::new
-  header['Last-Modified'] = CGI::rfc1123_date(Time.now)
+  header = {}
+  header['Last-Modified'] = CGI.rfc1123_date(Time.now)
   header['type']          = 'text/html'
   header['charset']       =  @conf.charset
   header['Content-Language'] = @conf.lang
   header['Pragma']           = 'no-cache'
   header['Cache-Control']    = 'no-cache'
-  print @cgi.header(header)
-  puts sources
 
-  nil # Don't move to the 'FrontPage'
+  ::Hiki::Response.new(sources, 200, header)
 end
 
 add_body_enter_proc(Proc.new do
