@@ -6,7 +6,7 @@ def todo(p, num = 8)
 
   todo_list = []
 
-  n = @db.load(p.unescapeHTML) || ''
+  n = @db.load(unescape_html(p)) || ''
   n.scan(todo_re) do |i|
     todo_list << {:priority => $1.to_i, :todo => $2}
   end
@@ -17,7 +17,7 @@ def todo(p, num = 8)
   c = 0
   todo_list.each do |t|
     break if (c += 1) > num
-    s << "#{'%02d' % t[:priority]} #{t[:todo].escapeHTML}<br>\n"
+    s << "#{'%02d' % t[:priority]} #{h(t[:todo])}<br>\n"
   end
   s
 end
