@@ -7,8 +7,8 @@ add_conf_proc("word_filter", WordFilterMessage.word_filter) do
   key_words = "#{pre}.words"
 
   if @cgi.request_method=="POST" and @mode=="saveconf"
-    @conf[key_use] = @cgi.params[key_use][0]
-    @conf[key_words] = @cgi.params[key_words][0]
+    @conf[key_use] = @request.params[key_use]
+    @conf[key_words] = @request.params[key_words]
   end
   old = @conf[key_words]
   @conf[key_words] ||= ""
@@ -20,7 +20,7 @@ add_conf_proc("word_filter", WordFilterMessage.word_filter) do
 <input type='checkbox' name='#{key_use}' id='#{key_use}' #{@conf[key_use] ? "checked='checked'" : ""}>
 <label for='#{key_use}'>#{m.use}</label>
 <p>#{m.regexp_by_line}</p>
-<textarea name='#{key_words}' col='80' row='40'>#{CGI.escapeHTML(@conf[key_words])}</textarea>
+<textarea name='#{key_words}' col='80' row='40'>#{h(@conf[key_words])}</textarea>
 </ul>
 EOT
 end
