@@ -1,53 +1,54 @@
+# -*- coding: utf-8 -*-
 def help_lineshelp_label
-   'Իٱ'
+   '行支援'
 end
 
 def help_wordshelp_label
-   'ʸٱ'
+   '文字支援'
 end
 
 def help_tablehelp_label
-   'ɽٱ'
+   '表支援'
 end
 
 def help_pluginhelp_label
-   'ץ饰ٱ'
+   'プラグイン支援'
 end
 
 def help_mathhelp_label
-   'ٱ'
+   '数式支援'
 end
 
 def help_heading_label
-   'Ф'
+   '見出し'
 end
 
 def help_list_label
-   'վ'
+   '箇条書'
 end
 
 def help_numbered_label
-   'ֹ'
+   '番号付'
 end
 
 def help_preformatted_label
-   ''
+   '整形済'
 end
 
 def help_quotation_label
-   ''
+   '引用'
 end
 
 def help_comment_label
-   ''
+   'コメント'
 end
 
 def help_cancel_label
-   ''
+   '解除'
 end
 
 def help_link_label
-   ''
+   'リンク'
 end
 
 def help_url_label
@@ -55,65 +56,65 @@ def help_url_label
 end
 
 def help_emphasized_label
-   'Ĵ'
+   '強調'
 end
 
 def help_strongly_label
-   ''
+   'さらに'
 end
 
 def help_struckout_label
-   ''
+   '取消線'
 end
 
 def help_definition_label
-   'Ѹ'
+   '用語解説'
 end
 
 def help_horizontal_label
-   'ʿ'
+   '水平線'
 end
 
 def help_cell_label
-   ''
+   'セル'
 end
 
 def help_headingcell_label
-   'Ф'
+   '見出し'
 end
 
 def help_rows_label
-   'Ϣ'
+   '縦連結'
 end
 
 def help_columns_label
-   'Ϣ'
+   '横連結'
 end
 
 def help_plugin_label
-   'ץ饰'
+   'プラグイン'
 end
 
 def help_br_label
-   ''
+   '改行'
 end
 
 def help_toc_label
-   'ܼ'
+   '目次'
 end
 
 def help_tochere_label
-   ''
+   'ここに'
 end
 
 def help_recent_label
-   'Ƕ'
+   '最近'
 end
 
 def help_display_label
-   'ǥץ쥤'
+   'ディスプレイ'
 end
 
 def help_inline_label
-   '饤'
+   'インライン'
 end
