@@ -1,7 +1,7 @@
 # $Id: parser.rb,v 1.22 2005-12-28 22:42:55 fdiary Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
-require 'style/default/hikidoc'
+require 'hikidoc'
 
 module Hiki
   class Parser_default
@@ -21,10 +21,12 @@ module Hiki
     end
     
     def initialize( conf )
+      @use_wiki_name = conf.use_wikiname
     end
 
     def parse( s, top_level = 2 )
-      HikiDoc.new( s, :level => top_level ).to_html
+      HikiDoc.to_html( s, :level => top_level,
+                       :use_wiki_name => @use_wiki_name )
     end
   end
 end
